<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function travel_master_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-master-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function travel_master_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-master-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function travel_master_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travel-master-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'travel_master_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function travel_master_pro_typography_options(){
        $choices = array(
            ''   => esc_html__( 'Default', 'travel-master-pro' ),
            'Rajdhani'   => esc_html__( 'Rajdhani', 'travel-master-pro' ),
            'Cherry Swash'   => esc_html__( 'Cherry Swash', 'travel-master-pro' ),
            'Philosopher'   => esc_html__( 'Philosopher', 'travel-master-pro' ),
            'Slabo 27px'   => esc_html__( 'Slabo 27px', 'travel-master-pro' ),
            'Dosis'   => esc_html__( 'Dosis', 'travel-master-pro' ),
            'News Cycle'     => esc_html__( 'News Cycle', 'travel-master-pro' ),
            'Pontano Sans'     => esc_html__( 'Pontano Sans', 'travel-master-pro' ),
            'Gudea'     => esc_html__( 'Gudea', 'travel-master-pro' ),
            'Quattrocento'     => esc_html__( 'Quattrocento', 'travel-master-pro' ),
            'Khand'     => esc_html__( 'Khand', 'travel-master-pro' ),
        );

        $output = apply_filters( 'travel_master_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'travel_master_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function travel_master_pro_selected_sidebar() {
        $travel_master_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'travel-master-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'travel-master-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'travel-master-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'travel-master-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'travel-master-pro' ),
        );

        $output = apply_filters( 'travel_master_pro_selected_sidebar', $travel_master_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function travel_master_pro_site_layout() {
        $travel_master_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'travel_master_pro_site_layout', $travel_master_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'travel_master_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function travel_master_pro_global_sidebar_position() {
        $travel_master_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'travel_master_pro_global_sidebar_position', $travel_master_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travel_master_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function travel_master_pro_sidebar_position() {
        $travel_master_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'travel_master_pro_sidebar_position', $travel_master_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travel_master_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function travel_master_pro_pagination_options() {
        $travel_master_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'travel-master-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'travel-master-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'travel-master-pro' ),
        );

        $output = apply_filters( 'travel_master_pro_pagination_options', $travel_master_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function travel_master_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'travel-master-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'travel-master-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'travel-master-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'travel-master-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'travel-master-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'travel-master-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'travel-master-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'travel-master-pro' ),
        );
        return apply_filters( 'travel_master_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'travel_master_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travel_master_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'travel-master-pro' ),
            'off'       => esc_html__( 'Disable', 'travel-master-pro' )
        );
        return apply_filters( 'travel_master_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'travel_master_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travel_master_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'travel-master-pro' ),
            'off'       => esc_html__( 'No', 'travel-master-pro' )
        );
        return apply_filters( 'travel_master_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'travel_master_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function travel_master_pro_sortable_sections() {
        $sections = array(
            'slider'                => esc_html__( 'Main Slider', 'travel-master-pro' ),
            'trip_search'           => esc_html__( 'Trip Search', 'travel-master-pro' ),
            'featured'              => esc_html__( 'Featured', 'travel-master-pro' ),
            'popular_destination'   => esc_html__( 'Popular Destination', 'travel-master-pro' ),
            'about'                 => esc_html__( 'About Us', 'travel-master-pro' ),
            'project'               => esc_html__( 'Project Gallery', 'travel-master-pro' ),
            'package'               => esc_html__( 'Package', 'travel-master-pro' ),
            'traveler_choice'       => esc_html__( 'Traveler Choice', 'travel-master-pro' ),
            'service'               => esc_html__( 'Services', 'travel-master-pro' ),
            'video_gallery'         => esc_html__( 'Video Gallery', 'travel-master-pro' ),
            'blog'                  => esc_html__( 'Blog', 'travel-master-pro' ),
            'discover_places'       => esc_html__( 'Discover Places', 'travel-master-pro' ),
            'testimonial'           => esc_html__( 'Testimonial', 'travel-master-pro' ),
            'subscription'          => esc_html__( 'Subscription', 'travel-master-pro' ),
        );
        return apply_filters( 'travel_master_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'travel_master_pro_main_slider_content_type' ) ) :
    /**
     * main slider Options
     * @return array site main slider options
     */
    function travel_master_pro_main_slider_content_type() {
        $travel_master_pro_main_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_main_slider_content_type = array_merge( $travel_master_pro_main_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_main_slider_content_type', $travel_master_pro_main_slider_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_service_content_type' ) ) :
    /**
     * service options
     * @return array site service options
     */
    function travel_master_pro_service_content_type() {
        $travel_master_pro_service_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_service_content_type = array_merge( $travel_master_pro_service_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_service_content_type', $travel_master_pro_service_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_blog_content_type' ) ) :
    /**
     * blog options
     * @return array site blog options
     */
    function travel_master_pro_blog_content_type() {
        $travel_master_pro_blog_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
            'recent'    => esc_html__( 'Recent', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_blog_content_type = array_merge( $travel_master_pro_blog_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_blog_content_type', $travel_master_pro_blog_content_type );


        return $output;
    }
endif;



if ( ! function_exists( 'travel_master_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function travel_master_pro_featured_content_type() {
        $travel_master_pro_featured_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_featured_content_type = array_merge( $travel_master_pro_featured_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_featured_content_type', $travel_master_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function travel_master_pro_popular_destination_content_type() {
        $travel_master_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_popular_destination_content_type = array_merge( $travel_master_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_popular_destination_content_type', $travel_master_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_package_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function travel_master_pro_package_content_type() {
        $travel_master_pro_package_content_type = array(
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_package_content_type = array_merge( $travel_master_pro_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_package_content_type', $travel_master_pro_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_traveler_choice_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function travel_master_pro_traveler_choice_content_type() {
        $travel_master_pro_traveler_choice_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_traveler_choice_content_type = array_merge( $travel_master_pro_traveler_choice_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_traveler_choice_content_type', $travel_master_pro_traveler_choice_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_discover_places_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function travel_master_pro_discover_places_content_type() {
        $travel_master_pro_discover_places_content_type = array(
            'page'      => esc_html__( 'Page', 'travel-master-pro' ),
            'post'      => esc_html__( 'Post', 'travel-master-pro' ),
            'category'  => esc_html__( 'Category', 'travel-master-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travel_master_pro_discover_places_content_type = array_merge( $travel_master_pro_discover_places_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travel-master-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travel-master-pro' ),
                'destination'   => esc_html__( 'Destination', 'travel-master-pro' ),
                'activity'      => esc_html__( 'Activity', 'travel-master-pro' ),
                ) );
        }

        $output = apply_filters( 'travel_master_pro_discover_places_content_type', $travel_master_pro_discover_places_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travel_master_pro_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function travel_master_pro_heading_tags() {
        
        $travel_master_pro_heading_tags = array(
			'h1'	=> esc_html__('H1', 'travel-master-pro'),
			'h2'	=> esc_html__('H2', 'travel-master-pro'),
			'h3'	=> esc_html__('H3', 'travel-master-pro'),
			'h4'	=> esc_html__('H4', 'travel-master-pro'),
			'h5'	=> esc_html__('H5', 'travel-master-pro'),
			'h6'	=> esc_html__('H6', 'travel-master-pro'),
			'p'		=> esc_html__('Paragraph', 'travel-master-pro'),
		);

        $output = apply_filters( 'travel_master_pro_heading_tags', $travel_master_pro_heading_tags );


        return $output;
    }
endif;

